@@ -50,6 +50,7 @@
 package com.openexchange.realtime.json.impl;
 
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
+
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -57,6 +58,8 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
+
+import com.openexchange.java.util.UUIDs;
 import com.openexchange.realtime.json.actions.SendAction;
 import com.openexchange.realtime.json.protocol.RTClientState;
 import com.openexchange.realtime.packet.ID;
@@ -101,6 +104,10 @@ public class RTClientStateImpl implements RTClientState {
 
     @Override
     public void enqueue(Stanza stanza) {
+        if (stanza.getId() == null || stanza.getId().trim().equals("")) {
+        	stanza.setId(UUIDs.getUnformattedStringFromRandom());
+        }
+    	stanza.trace("Using ID: " + stanza.getId());
         if (stanza.getSequenceNumber() != -1) {
             lock();
             try {
